@@ -1,9 +1,11 @@
-import { pushRetentionArgument, Labels, pushLabelsArgument } from '.';
+import { pushRetentionArgument, Labels, pushLabelsArgument, TimeSeriesDuplicatePolicies, pushChunkSizeArgument, pushDuplicatePolicy } from '.';
 
 export const FIRST_KEY_INDEX = 1;
 
 interface AlterOptions {
     RETENTION?: number;
+    CHUNK_SIZE?: number;
+    DUPLICATE_POLICY?: TimeSeriesDuplicatePolicies;
     LABELS?: Labels;
 }
 
@@ -12,6 +14,10 @@ export function transformArguments(key: string, options?: AlterOptions): Array<s
 
     pushRetentionArgument(args, options?.RETENTION);
 
+    pushChunkSizeArgument(args, options?.CHUNK_SIZE);
+
+    pushDuplicatePolicy(args, options?.DUPLICATE_POLICY);
+
     pushLabelsArgument(args, options?.LABELS);
 
     return args;
