@@ -4,11 +4,20 @@ import testUtils, { GLOBAL } from '../test-utils';
 import { transformArguments } from './CREATERULE';
 
 describe('CREATERULE', () => {
-    it('transformArguments', () => {
-        assert.deepEqual(
-            transformArguments('source', 'destination', TimeSeriesAggregationType.AVERAGE, 1),
-            ['TS.CREATERULE', 'source', 'destination', 'AGGREGATION', 'avg', '1']
-        );
+    describe('transformArguments', () => {
+        it('without options', () => {
+            assert.deepEqual(
+                transformArguments('source', 'destination', TimeSeriesAggregationType.AVERAGE, 1),
+                ['TS.CREATERULE', 'source', 'destination', 'AGGREGATION', 'AVG', '1']
+            );
+        });
+
+        it('with alignTimestamp', () => {
+            assert.deepEqual(
+                transformArguments('source', 'destination', TimeSeriesAggregationType.AVERAGE, 1, 1),
+                ['TS.CREATERULE', 'source', 'destination', 'AGGREGATION', 'AVG', '1', '1']
+            );
+        });
     });
 
     testUtils.testWithClient('client.ts.createRule', async client => {
